[GitHub Pages](https://jameskabbes.github.io/the_garden)<br>
[PyPI](https://pypi.org/project/kabbes-the-garden)

# the_garden
A build of commonly-used open-source tools

<br> 

# Installation
`pip install kabbes_the_garden`

<br>

# Usage
For more in-depth documentation, read the information provided on the Pages. Or better yet, read the source code.

## Python Script

```python
import the_garden
```

```python
print (the_garden.github_accounts)
```

## Terminal


```
python -m the_garden
```

<br>

# Author
James Kabbes
